@@ -87,6 +87,11 @@ class Service(org.maemo.hermes.engine.service.Service):
                 return []
             else:
                 raise e
+        except Exception, e:
+            if e.message == 'This method requires authentication.':
+                raise org.maemo.hermes.engine.service.CredentialsExpiredException('Twitter')
+            else:
+                raise e
         
     
     
