@@ -2,7 +2,7 @@
 
 import unittest
 
-from unit.test_facebook import TestFacebookService
+from unit.test_facebook import TestFacebookService, TestFacebookAPI
 from unit.test_gravatar import TestGravatarService
 from unit.test_linkedin import TestLinkedInService
 from unit.test_twitter import TestTwitterService
@@ -13,6 +13,9 @@ from unit.test_phonenumber import TestPhoneNumber
 from integration.test_gravatar import IntegrationTestGravatarService
 from integration.test_linkedinapi import IntegrationTestLinkedInApi
 from integration.test_twitter import IntegrationTestTwitterService
+from integration.test_oauth2 import IntegrationTestOAuth2
+from integration.test_facebook import IntegrationTestFacebook
+
 
 if __name__ == '__main__':
     unittest.main()
